﻿using Syncfusion.DataSource;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Reflection;
using Xamarin.Forms;
using Syncfusion.ListView.XForms;
using Syncfusion.GridCommon.ScrollAxis;

namespace ListViewSample
{
    public partial class MainPage : ContentPage
    {
        #region Fields

        Button popUpContent;
        Button popUpContent1;
        StackLayout stackLayout;
        int sortorder = 0;
        Contacts contact;
        VisualContainer visualContainer;
        ScrollAxisBase scrollRows;

        #endregion

        #region Constructor

        public MainPage()
        {
            InitializeComponent();
            InitializeDescriptor();
            InitializeView();
        }

        private void InitializeDescriptor()
        {
            listView.DataSource.SortDescriptors.Add(new SortDescriptor() { PropertyName = "ContactName", Direction = ListSortDirection.Ascending });
            listView.DataSource.GroupDescriptors.Add(new GroupDescriptor()
            {
                PropertyName = "ContactName",
                KeySelector = (object obj1) =>
                {
                    var item = (obj1 as Contacts);
                    return item.ContactName[0].ToString();
                }
            });
        }
        private void InitializeView()
        {
            visualContainer = listView.GetType().GetRuntimeProperties().First(p => p.Name == "VisualContainer").GetValue(listView) as VisualContainer;
            scrollRows = visualContainer.GetType().GetRuntimeProperties().First(p => p.Name == "ScrollRows").GetValue(visualContainer) as ScrollAxisBase;
            scrollRows.Changed += ScrollRows_Changed;
        }

        #endregion

        #region Private Methods

        #endregion

        #region CallBacks

        private void ListView_ItemTapped(object sender, Syncfusion.ListView.XForms.ItemTappedEventArgs e)
        {
            popUpLayout.Dismiss();
        }

        private void ListView_ItemHolding(object sender, Syncfusion.ListView.XForms.ItemHoldingEventArgs e)
        {
            contact = e.ItemData as Contacts;
            
            popUpContent = new Button()
            {
                Text = "Sort",
                FontSize = 14,
                TextColor = Color.White,
                WidthRequest = 100,
                BackgroundColor = Color.Teal,
                HeightRequest = 35
            };
            popUpContent.Clicked += PopUpContent_Clicked;
            popUpContent1 = new Button()
            {
                Text = "Delete",
                FontSize = 14,
                TextColor = Color.White,
                BackgroundColor = Color.Teal,
                WidthRequest = 100,
                HeightRequest = 35
            };
            popUpContent1.Clicked += PopUpContent1_Clicked;

            stackLayout = new StackLayout()
            {
                BackgroundColor = Color.Teal,
                Children = { popUpContent, popUpContent1 }
            };

            var index = listView.DataSource.DisplayItems.IndexOf(e.ItemData);
            var y = scrollRows.GetVisibleLineAtLineIndex(index);

            popUpLayout.ShowPopup(stackLayout, Constraint.Constant(10), Constraint.Constant(y.Origin));
        }

        private void ScrollRows_Changed(object sender, ScrollChangedEventArgs e)
        {
            popUpLayout.Dismiss();
        }
        private void PopUpContent1_Clicked(object sender, EventArgs e)
        {
            viewModel.Contactsinfo.Remove(contact);
            popUpLayout.Dismiss();
        }

        private void PopUpContent_Clicked(object sender, EventArgs e)
        {
            listView.DataSource.SortDescriptors.Clear();
            if (sortorder == 0)
            {
                listView.DataSource.SortDescriptors.Add(new SortDescriptor { PropertyName = "ContactName", Direction = ListSortDirection.Descending });
                sortorder = 1;
            }
            else
            {
                listView.DataSource.SortDescriptors.Add(new SortDescriptor { PropertyName = "ContactName", Direction = ListSortDirection.Ascending });
                sortorder = 0;
            }
            popUpLayout.Dismiss();
            listView.RefreshView();
        }

        #endregion

    }
}

